@@ -407,9 +407,15 @@ def check_required_dependency(req_file: str):
     pkg_resources.require(open(req_file).read())
 
 
-async def _mikrotik_probe(host, mikrotik_api_cls, creds, num_retries=1, **kwargs):
+async def _mikrotik_probe(host,
+                          mikrotik_api_cls,
+                          creds,
+                          raise_errors,
+                          num_retries=1,
+                          **kwargs):
     """Probe the mikrotik API of a host using (username, password) tuples."""
     client = None
+    last_err = None
     if creds:
         mikrotik_api = mikrotik_api_cls(host, None, None, **kwargs)
         try:
@@ -419,12 +425,18 @@ async def _mikrotik_probe(host, mikrotik_api_cls, creds, num_retries=1, **kwargs
                 try:
                     await asyncio.wait_for(mikrotik_api.connect(), 5.0)
                     for cred in creds:
+                        last_err = None
                         mikrotik_api._user = cred[0]
                         mikrotik_api._pass = cred[1]
                         try:
                             await asyncio.wait_for(mikrotik_api.login(), 5.0)
-                        except MikrotikApiError:
+                        except MikrotikApiError as err:
+                            last_err = err
                             continue  # no match to username/password
+                        except asyncio.CancelledError:
+                            raise
+                        except Exception as err:
+                            last_err = err
                         client = mikrotik_api
                         return client
                 except (MikrotikApiError, OSError, asyncio.TimeoutError) as err:
@@ -432,14 +444,21 @@ async def _mikrotik_probe(host, mikrotik_api_cls, creds, num_retries=1, **kwargs
         finally:
             if not client:
                 await mikrotik_api.close()
+            if last_err and raise_errors:
+                raise last_err
     return client
 
 
-async def mikrotik_api_probe(host, mikrotik_api_cls, creds, **kwargs):
+async def mikrotik_api_probe(host,
+                             mikrotik_api_cls,
+                             creds,
+                             raise_errors=True,
+                             **kwargs):
     """Try to connect to a Mikrotik host using a list of (username, password) credentials."""
     pend = [
         asyncio.create_task(x) for x in [
-            _mikrotik_probe(host, mikrotik_api_cls, creds, enable_ssl=x, **kwargs)
+            _mikrotik_probe(
+                host, mikrotik_api_cls, creds, raise_errors, enable_ssl=x, **kwargs)
             for x in (True, False)
         ]
     ]
